Usage
formr_api_aggregate(results, item_list, min_items = 2)
Arguments
- results
A data frame/tibble containing the run results.
- item_list
A data frame containing item metadata (names, types, choices).
- min_items
Minimum number of valid items required to calculate a mean (default 2).
Value
The results data.frame with one added numeric column per scale (the row mean of its items); scale reliability stored in attributes.