Skip to contents

Creates one or more sessions. If codes is NULL, one random session is created. If codes is provided, tries to create sessions with those specific codes.

Usage

formr_api_create_session(
  run_name,
  codes = NULL,
  testing = FALSE,
  verbose = TRUE
)

Arguments

run_name

Name of the run.

codes

Character vector of codes. If NULL, creates one random code.

testing

Logical. Mark these sessions as testing?

verbose

Logical. If TRUE (default), reports progress via message().

Value

Invisibly the API response: a list with the created sessions and, for any that failed, an errors data.frame to inspect.