Skip to contents

Invalidates the current access token on the server and clears the local session state.

Usage

formr_api_logout(verbose = TRUE)

Arguments

verbose

Logical. If TRUE (default), reports progress via message().

Value

Invisibly TRUE on success (or FALSE if there was no active session); called to revoke the access token on the server and clear the local session.