Reverse Items and Update Labels
formr_api_reverse.RdReverses numeric items ending in 'R' based on metadata bounds.
Critically, it also updates haven::labelled attributes so that
the text labels point to the new, reversed values.
formr_api_reverse.RdReverses numeric items ending in 'R' based on metadata bounds.
Critically, it also updates haven::labelled attributes so that
the text labels point to the new, reversed values.