Get or Update Run Settings
formr_api_run_settings.RdRetrieve the settings for one or more runs as a tidy data frame, or update them by providing a named list of new values.
Arguments
- run_name
Name of the run (or a vector of names).
- settings
A list of settings to update (e.g.,
list(public = 1, locked = TRUE)). If NULL, returns the current settings.- verbose
Logical. If TRUE (default), reports progress via
message().