Skip to contents

Uploads local file(s) to the run. Accepts a single file path, a vector of file paths, or a directory path (which will upload all files within that directory).

Usage

formr_api_upload_file(run_name, path, verbose = TRUE)

Arguments

run_name

Name of the run.

path

Local path to the file, a vector of paths, or a directory path.

verbose

Logical. If TRUE (default), reports progress via message().

Value

Invisibly returns a list of server responses.