Skip to contents

Disconnects from formr if connected.

Usage

formr_disconnect(host = formr_last_host())

Arguments

host

defaults to formr_last_host(), which defaults to https://rforms.org

Value

Invisibly TRUE on a successful logout; called to log out and clear the active session.

Examples

if (FALSE) { # \dontrun{
# Not run: needs a live formr server and an authenticated session.
formr_disconnect()
} # }