Skip to contents

This function returns the default or the last specified host if called without an argument. It changes the host when called with an argument.

Usage

formr_last_host(host = NULL)

Arguments

host

defaults to https://rforms.org

Value

the last specified host

Examples

formr_last_host("https://rforms.org")
#> [1] "https://rforms.org"
formr_last_host()
#> [1] "https://rforms.org"