Skip to contents

formr has a specific module for randomisation. After connecting using formr_connect() you can download the assigned random groups and merge them with your data.

Usage

formr_shuffled(run_name, host = formr_last_host())

Arguments

run_name

case-sensitive name of the run in which you randomised participants

host

defaults to formr_last_host(), which defaults to https://rforms.org

Value

A data.frame (parsed JSON) of random group assignments keyed by session.

Examples

if (FALSE) { # \dontrun{
# Not run: needs a live formr server and an authenticated session.
formr_connect(email = 'you@example.net', password = 'zebrafinch' )
formr_shuffled(run_name = 'different_drills' )
} # }