Download random groups
formr_user_detail.Rdformr collects information about users' progression through the run
After connecting using formr_connect()
you can download a table showing their progression through the run.
Usage
formr_user_detail(run_name, host = formr_last_host())Arguments
- run_name
case-sensitive name of the run in which you randomised participants
- host
defaults to
formr_last_host(), which defaults to https://rforms.org
Examples
if (FALSE) { # \dontrun{
# Not run: needs a live formr server and an authenticated session.
formr_connect(email = 'you@example.net', password = 'zebrafinch' )
formr_user_detail(run_name = 'different_drills' )
} # }