Just a simple shorthand so that inexperienced R users don't have
to use somewhat complex functions such as grepl() and stringr::str_detect()
with non-default arguments (e.g. fixed params).
Usage
haystack %contains% needle
Arguments
- haystack
string in which you search
- needle
string to search for
Value
A logical vector, TRUE where haystack contains needle as a fixed substring.
Examples
"1, 2, 3, 4, you" %contains% "you"
#> [1] TRUE
"1, 2, 3, 4, you" %contains% 1 # unlike str_detect casts all needles as characters
#> [1] TRUE
"1, 2, 3, 4, you" %contains% 343
#> [1] FALSE