Skip to contents

a simple utility functions to avoid that looped Skip Backwards/Skip Forwards in formr are true repeatedly.

Usage

next_day(date = NULL)

Arguments

date

defaults to .formr$last_action_date, a hidden variable that is automatically set by rforms.org. Will be coerced to POSIXct.

Value

A POSIXct: midnight at the start of the day after date.

Examples

next_day(Sys.time())
#> [1] "2026-06-13 UTC"