Backup a study
formr_api_backup_run.RdDownloads the full run structure, all survey items, attached files, and results. Saves everything into a structured folder.
formr_api_backup_run.RdDownloads the full run structure, all survey items, attached files, and results. Saves everything into a structured folder.