Create a new run
formr_api_create_run.RdCreates one or more new runs on the server. Prints a confirmation message with the public link for each.
Arguments
- name
A character vector of names for the new runs (must be unique).
- verbose
Logical. If TRUE (default), reports progress via
message().