Create a new run
formr_api_create_run.RdCreates one or more new runs on the server. Prints a confirmation message with the public link for each.
formr_api_create_run.RdCreates one or more new runs on the server. Prints a confirmation message with the public link for each.