Delete file(s) from a run
formr_api_delete_file.RdRemoves file attachment(s) from the run. Accepts a single filename, a vector of filenames, or a local directory path (which will delete files on the server that match the names of the files in the local directory).